"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const blessed = require("blessed");
const frame_1 = require("../ui/frame");
const body_1 = require("../ui/body");
const branch_selector_1 = require("../ui/branch-selector");
const git_branch_1 = require("../git/git-branch");
const git_checkout_1 = require("../git/git-checkout");
function branchSelectionScreen() {
    return __awaiter(this, void 0, void 0, function* () {
        const screen = blessed.screen({ smartCSR: true });
        try {
            let done = false;
            const body = body_1.default(screen);
            const gitBranches = yield git_branch_1.default();
            const branchSelector = new branch_selector_1.default(body, gitBranches);
            screen.key(['up', 'k'], () => branchSelector.up());
            screen.key(['down', 'j'], () => branchSelector.down());
            screen.key('enter', () => __awaiter(this, void 0, void 0, function* () {
                done = yield handleEnter(screen, branchSelector);
            }));
            const input = blessed.textbox({ left: 0, bottom: 0, height: 1 });
            screen.append(input);
            screen.key(':', () => {
                input.setValue(':');
                input.readInput((err, value) => __awaiter(this, void 0, void 0, function* () {
                    input.setValue('');
                    done = yield handleInput(screen, branchSelector, value);
                }));
            });
            screen.key(['escape', 'q', 'C-c'], () => process.exit(0));
            for (;;) {
                if (done) {
                    break;
                }
                branchSelector.update();
                screen.render();
                yield frame_1.default();
            }
        }
        catch (err) {
            exitWithError(screen, err);
        }
    });
}
exports.default = branchSelectionScreen;
function handleEnter(screen, branchSelector) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const branch = branchSelector.getSelection();
            const result = yield git_checkout_1.default(branch.name);
            exitWithMessage(screen, result);
            return true;
        }
        catch (err) {
            exitWithError(screen, err);
        }
        return false;
    });
}
function handleInput(screen, branchSelector, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const force = value.match(/!$/);
        const val = value.replace(/^:|!$/g, '');
        try {
            switch (val) {
                case 'de':
                    const branch = branchSelector.getSelection();
                    const delOpt = force ? '-D' : '-d';
                    const result = yield git_branch_1.default(delOpt, branch.name);
                    exitWithMessage(screen, [...result, ''].join('\n'));
                    return true;
                case 'q':
                case 'quit':
                    process.exit(0);
                    return true;
            }
        }
        catch (err) {
            exitWithError(screen, err);
        }
        return false;
    });
}
function exitWithMessage(screen, message) {
    screen.destroy();
    process.stdout.write(message);
    process.exit(0);
}
function exitWithError(screen, message) {
    screen.destroy();
    process.stderr.write(message);
    process.exit(1);
}
//# sourceMappingURL=branch-selection.js.map