"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const blessed = require("blessed");
class BranchSelector {
    constructor(body, gitBranches) {
        this.selected = 0;
        this.branches = [];
        this.body = body;
        this.parseBranches(gitBranches);
    }
    parseBranches(gitBranches) {
        gitBranches.forEach((rawBranch, index) => {
            const isCurrent = rawBranch.charAt(0) === '*';
            if (isCurrent) {
                this.selected = index;
            }
            const name = rawBranch.trim().replace(/^\*\s/, '');
            const node = blessed.text({ content: name, top: index });
            const branch = { name, node, isCurrent };
            this.branches.push(branch);
            this.body.append(node);
        });
    }
    up() {
        this.selected = Math.max(0, this.selected - 1);
    }
    down() {
        this.selected = Math.min(this.branches.length - 1, this.selected + 1);
    }
    getSelection() {
        return this.branches[this.selected];
    }
    update() {
        this.branches.forEach((branch, index) => {
            const content = [];
            let fg = 'white';
            if (branch.isCurrent) {
                content.push('*');
            }
            else {
                content.push(' ');
            }
            if (this.selected === index) {
                content.push('\u25cf');
                fg = 'green';
            }
            else {
                content.push(' ');
            }
            content.push(branch.name);
            branch.node.content = content.join(' ');
            branch.node.style.fg = fg;
        });
    }
}
exports.default = BranchSelector;
//# sourceMappingURL=branch-selector.js.map